@@ -18,7 +18,7 @@
  */
 
 /***************************************************************************
- * Copyright (C) 2017-2024 ZmartZone Holding BV
+ * Copyright (C) 2017-2025 ZmartZone Holding BV
  * Copyright (C) 2013-2017 Ping Identity Corporation
  * All rights reserved.
  *
@@ -126,7 +126,7 @@ static apr_status_t oidc_cache_file_read(request_rec *r, const char *path, apr_f
 /*
  * write a specified number of bytes from a buffer to a cache file
  */
-static apr_status_t oidc_cache_file_write(request_rec *r, const char *path, apr_file_t *fd, void *buf,
+static apr_status_t oidc_cache_file_write(request_rec *r, const char *path, apr_file_t *fd, const void *buf,
 					  const apr_size_t len) {
 
 	apr_status_t rc = APR_SUCCESS;
@@ -307,8 +307,8 @@ static apr_status_t oidc_cache_file_clean(request_rec *r) {
 			/* skip non-cache entries, cq. the ".", ".." and the metadata file */
 			if ((fi.name[0] == OIDC_CHAR_DOT) ||
 			    (_oidc_strstr(fi.name, OIDC_CACHE_FILE_PREFIX) != fi.name) ||
-			    ((_oidc_strcmp(fi.name,
-					   oidc_cache_file_name(r, "cache-file", OIDC_CACHE_FILE_LAST_CLEANED)) == 0)))
+			    (_oidc_strcmp(fi.name,
+					  oidc_cache_file_name(r, "cache-file", OIDC_CACHE_FILE_LAST_CLEANED)) == 0))
 				continue;
 
 			/* get the fully qualified path to the cache file and open it */
@@ -409,7 +409,7 @@ static apr_byte_t oidc_cache_file_set(request_rec *r, const char *section, const
 		return FALSE;
 
 	/* next write the value */
-	oidc_cache_file_write(r, path, fd, (void *)value, info.len);
+	oidc_cache_file_write(r, path, fd, (const void *)value, info.len);
 
 	/* unlock and close the written file */
 	apr_file_unlock(fd);
