@@ -164,6 +164,8 @@ apr_byte_t oidc_util_request_has_parameter(request_rec *r, const char *param);
 apr_byte_t oidc_util_request_parameter_get(request_rec *r, char *name, char **value);
 int oidc_util_http_send(request_rec *r, const char *data, size_t data_len, const char *content_type,
 			int success_rvalue);
+int oidc_util_http_content_prep(request_rec *r, const char *data, size_t data_len, const char *content_type);
+int oidc_util_http_content_send(request_rec *r);
 apr_byte_t oidc_util_read_form_encoded_params(request_rec *r, apr_table_t *table, char *data);
 apr_byte_t oidc_util_read_post_params(request_rec *r, apr_table_t *table, apr_byte_t propagate,
 				      const char *strip_param_name);
