@@ -18,7 +18,7 @@
  */
 
 /***************************************************************************
- * Copyright (C) 2017-2024 ZmartZone Holding BV
+ * Copyright (C) 2017-2025 ZmartZone Holding BV
  * Copyright (C) 2013-2017 Ping Identity Corporation
  * All rights reserved.
  *
@@ -61,23 +61,23 @@ static int TST_RC;
 #define TST_ASSERT(message, expression)                                                                                \
 	TST_RC = (expression);                                                                                         \
 	if (!TST_RC) {                                                                                                 \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%d"), __FUNCTION__, message, TST_RC, 1);                              \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%d"), __FUNCTION__, message, TST_RC, 1);                       \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
 #define TST_ASSERT_ERR(message, expression, pool, err)                                                                 \
 	TST_RC = (expression);                                                                                         \
 	if (!TST_RC) {                                                                                                 \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%d") " %s", __FUNCTION__, message, TST_RC, 1,                         \
-			oidc_jose_e2s(pool, err));                                                                     \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%d") " %s", __FUNCTION__, message, TST_RC, 1,                  \
+			 oidc_jose_e2s(pool, err));                                                                    \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
 #define TST_ASSERT_CJOSE_ERR(message, expression, pool, cjose_err)                                                     \
 	TST_RC = (expression);                                                                                         \
 	if (!TST_RC) {                                                                                                 \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%d") " %s", __FUNCTION__, message, TST_RC, 1,                         \
-			oidc_cjose_e2s(pool, cjose_err));                                                              \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%d") " %s", __FUNCTION__, message, TST_RC, 1,                  \
+			 oidc_cjose_e2s(pool, cjose_err));                                                             \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
@@ -85,8 +85,8 @@ static int TST_RC;
 	TST_RC =                                                                                                       \
 	    (result && expected) ? (_oidc_strcmp(result, expected) != 0) : ((result != NULL) || (expected != NULL));   \
 	if (TST_RC) {                                                                                                  \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%s"), __FUNCTION__, message, result ? result : "(null)",              \
-			expected ? expected : "(null)");                                                               \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%s"), __FUNCTION__, message, result ? result : "(null)",       \
+			 expected ? expected : "(null)");                                                              \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
@@ -94,21 +94,21 @@ static int TST_RC;
 	TST_RC = (result && expected) ? (_oidc_strncmp(result, expected, len) != 0)                                    \
 				      : ((result != NULL) || (expected != NULL));                                      \
 	if (TST_RC) {                                                                                                  \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%s"), __FUNCTION__, message, result ? result : "(null)",              \
-			expected ? expected : "(null)");                                                               \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%s"), __FUNCTION__, message, result ? result : "(null)",       \
+			 expected ? expected : "(null)");                                                              \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
 #define TST_ASSERT_LONG(message, result, expected)                                                                     \
 	if (result != expected) {                                                                                      \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%ld"), __FUNCTION__, message, result, expected);                      \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%ld"), __FUNCTION__, message, result, expected);               \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
 #define TST_ASSERT_BYTE(message, result, expected)                                                                     \
 	if (result != expected) {                                                                                      \
-		sprintf(TST_ERR_MSG, TST_FORMAT("%s"), __FUNCTION__, message, result ? "TRUE" : "FALSE",               \
-			expected ? "TRUE" : "FALSE");                                                                  \
+		snprintf(TST_ERR_MSG, 4096, TST_FORMAT("%s"), __FUNCTION__, message, result ? "TRUE" : "FALSE",        \
+			 expected ? "TRUE" : "FALSE");                                                                 \
 		return TST_ERR_MSG;                                                                                    \
 	}
 
@@ -129,7 +129,7 @@ static char *_jwk_parse(apr_pool_t *pool, const char *s, oidc_jwk_t **jwk, oidc_
 }
 
 static char *test_private_key_parse(apr_pool_t *pool) {
-	oidc_jose_error_t err;
+	oidc_jose_error_t err = {{'\0'}, 0, {'\0'}, {'\0'}};
 	BIO *input = NULL;
 	oidc_jwk_t *jwk = NULL;
 	int isPrivateKey = 1;
@@ -140,8 +140,8 @@ static char *test_private_key_parse(apr_pool_t *pool) {
 	const char ecPrivateKeyFile[512];
 
 	char *dir = getenv("srcdir") ? getenv("srcdir") : ".";
-	sprintf((char *)rsaPrivateKeyFile, "%s/%s", dir, "/test/private.pem");
-	sprintf((char *)ecPrivateKeyFile, "%s/%s", dir, "/test/ecpriv.key");
+	snprintf((char *)rsaPrivateKeyFile, 512, "%s/%s", dir, "/test/private.pem");
+	snprintf((char *)ecPrivateKeyFile, 512, "%s/%s", dir, "/test/ecpriv.key");
 
 	input = BIO_new(BIO_s_file());
 	TST_ASSERT_ERR("test_private_key_parse_BIO_new_RSA_private_key", input != NULL, pool, err);
@@ -191,7 +191,7 @@ static char *test_private_key_parse(apr_pool_t *pool) {
 
 static char *test_public_key_parse(apr_pool_t *pool) {
 
-	oidc_jose_error_t err;
+	oidc_jose_error_t err = {{'\0'}, 0, {'\0'}, {'\0'}};
 	oidc_jwk_t *jwk, *jwkCert = NULL;
 
 	BIO *input, *inputCert = NULL;
@@ -204,9 +204,9 @@ static char *test_public_key_parse(apr_pool_t *pool) {
 	const char certificateFile[512];
 	const char ecCertificateFile[512];
 	char *dir = getenv("srcdir") ? getenv("srcdir") : ".";
-	sprintf((char *)publicKeyFile, "%s/%s", dir, "/test/public.pem");
-	sprintf((char *)certificateFile, "%s/%s", dir, "/test/certificate.pem");
-	sprintf((char *)ecCertificateFile, "%s/%s", dir, "/test/eccert.pem");
+	snprintf((char *)publicKeyFile, 512, "%s/%s", dir, "/test/public.pem");
+	snprintf((char *)certificateFile, 512, "%s/%s", dir, "/test/certificate.pem");
+	snprintf((char *)ecCertificateFile, 512, "%s/%s", dir, "/test/eccert.pem");
 
 	input = BIO_new(BIO_s_file());
 	TST_ASSERT_ERR("test_public_key_parse_BIO_new_public_key", input != NULL, pool, err);
@@ -1073,6 +1073,8 @@ static char *test_logout_request(request_rec *r) {
 	    "https://idp.example.com/"
 	    "endsession?post_logout_redirect_uri=https%3A%2F%2Fwww.example.com%2Floggedout&client_id=myclient&foo=bar");
 
+	oidc_session_free(r, session);
+
 	return 0;
 }
 
@@ -1770,6 +1772,35 @@ static char *test_set_app_infos(request_rec *r) {
 	return 0;
 }
 
+static char *test_check_cookie_domain(request_rec *r) {
+	apr_byte_t rv = FALSE;
+	oidc_cfg_t *c = ap_get_module_config(r->server->module_config, &auth_openidc_module);
+	oidc_session_t *session = NULL;
+
+	oidc_session_load(r, &session);
+	oidc_session_set_cookie_domain(r, session, "ab001sb161djbn.xyz.com");
+	apr_table_set(r->headers_in, "Host", "ab001SB161djbn.xyz.com");
+
+	rv = oidc_check_cookie_domain(r, c, session);
+	TST_ASSERT_BYTE("oidc_check_cookie_domain", rv, TRUE);
+
+	rv = oidc_request_check_cookie_domain(r, c, "https://WWW.example.com/protected/index.html");
+	TST_ASSERT_BYTE("oidc_request_check_cookie_domain", rv, TRUE);
+
+	c->cookie_domain = ".XYZ.com";
+	rv = oidc_request_check_cookie_domain(r, c, "https://ab001sb161djbn.xyz.com/protected/index.html");
+	TST_ASSERT_BYTE("oidc_request_check_cookie_domain", rv, TRUE);
+
+	c->cookie_domain = "ab001SB161djbn.xyz.com";
+	rv = oidc_request_check_cookie_domain(r, c, "https://ab001sb161djbn.xyz.com/protected/index.html");
+	TST_ASSERT_BYTE("oidc_request_check_cookie_domain", rv, TRUE);
+
+	c->cookie_domain = NULL;
+	oidc_session_free(r, session);
+
+	return 0;
+}
+
 static char *all_tests(apr_pool_t *pool, request_rec *r) {
 	char *message;
 	TST_RUN(test_private_key_parse, pool);
@@ -1815,6 +1846,7 @@ static char *all_tests(apr_pool_t *pool, request_rec *r) {
 #endif
 
 	TST_RUN(test_logout_request, r);
+	TST_RUN(test_check_cookie_domain, r);
 
 	return 0;
 }
@@ -1865,8 +1897,8 @@ static request_rec *test_setup(apr_pool_t *pool) {
 
 	oidc_dir_cfg_t *d_cfg = oidc_cfg_dir_config_create(request->pool, NULL);
 
-	request->server->module_config = apr_pcalloc(request->pool, sizeof(ap_conf_vector_t *) * kEls);
-	request->per_dir_config = apr_pcalloc(request->pool, sizeof(ap_conf_vector_t *) * kEls);
+	request->server->module_config = apr_pcalloc(request->pool, sizeof(void) * kEls);
+	request->per_dir_config = apr_pcalloc(request->pool, sizeof(void) * kEls);
 	ap_set_module_config(request->server->module_config, &auth_openidc_module, cfg);
 	ap_set_module_config(request->per_dir_config, &auth_openidc_module, d_cfg);
 
